Package: predint
Type: Package
Title: Prediction Intervals
Version: 2.2.1
Authors@R: person("Max", "Menssen", email = "menssen@cell.uni-hannover.de",
                  role = c("aut", "cre"))
Description: An implementation of prediction intervals for overdispersed count data,
            for overdispersed binomial data and for linear random effects models.
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
Imports: stats, graphics, methods
RoxygenNote: 7.2.3
Suggests: rmarkdown, knitr, testthat (>= 3.0.0)
Config/testthat/edition: 3
Depends: R (>= 2.10), ggplot2, lme4, MASS
URL: https://github.com/MaxMenssen/predint
BugReports: https://github.com/MaxMenssen/predint/issues
Author: Max Menssen [aut, cre]
Maintainer: Max Menssen <menssen@cell.uni-hannover.de>
Built: R 4.4.0; ; 2024-05-07 09:56:05 UTC; unix
