# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,predint)
S3method(plot,predint)
S3method(print,predint)
S3method(summary,predint)
export(bb_pi)
export(beta_bin_pi)
export(bisection)
export(boot_predint)
export(lmer_bs)
export(lmer_pi)
export(lmer_pi_futmat)
export(lmer_pi_futvec)
export(lmer_pi_unstruc)
export(nb_pi)
export(neg_bin_pi)
export(normal_pi)
export(pi_rho_est)
export(qb_pi)
export(qp_pi)
export(quasi_bin_pi)
export(quasi_pois_pi)
export(rbbinom)
export(rnbinom)
export(rqbinom)
export(rqpois)
import(ggplot2)
importFrom(MASS,glm.nb)
importFrom(graphics,abline)
importFrom(graphics,lines)
importFrom(lme4,VarCorr)
importFrom(lme4,bootMer)
importFrom(lme4,fixef)
importFrom(lme4,lFormula)
importFrom(methods,is)
importFrom(stats,coef)
importFrom(stats,glm)
importFrom(stats,na.omit)
importFrom(stats,qnorm)
importFrom(stats,quasibinomial)
importFrom(stats,quasipoisson)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,var)
importFrom(stats,vcov)
